Class: Daisy::DataDisplay::TableComponent
- Inherits:
-
LocoMotion::BaseComponent
- Object
- ViewComponent::Base
- LocoMotion::BaseComponent
- Daisy::DataDisplay::TableComponent
- Defined in:
- app/components/daisy/data_display/table_component.rb
Overview
The top-level head / body / row+ slots and the section+
slot are mutually exclusive — per the template, providing any
section+ makes the top-level head, body, and row+ silently
ignored.
The Table component creates structured data tables with support for headers, multiple sections, and complex layouts. It provides a clean, semantic way to display tabular data while maintaining proper HTML structure.
Defined Under Namespace
Classes: BodyColumnComponent, BodyComponent, BodyRowComponent, HeadColumnComponent, HeadComponent, SectionComponent
Constant Summary
Constants inherited from LocoMotion::BaseComponent
LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS
Instance Attribute Summary
Attributes inherited from LocoMotion::BaseComponent
Instance Method Summary collapse
- #before_render ⇒ Object
-
#initialize(*args, **kws, &block) ⇒ TableComponent
constructor
Instantiate a new Table component.
Methods inherited from LocoMotion::BaseComponent
build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces
Methods included from LocoMotion::Concerns::InspectableComponent
Constructor Details
#initialize(*args, **kws, &block) ⇒ TableComponent
Instantiate a new Table component. This component takes no content;
you may optionally use the head slot, and must use one of the
body or row+ slots (or section+, which supersedes all three —
see the note above).
218 219 220 |
# File 'app/components/daisy/data_display/table_component.rb', line 218 def initialize(*args, **kws, &block) super end |
Instance Method Details
#before_render ⇒ Object
222 223 224 |
# File 'app/components/daisy/data_display/table_component.rb', line 222 def before_render setup_component end |