Class: Daisy::DataDisplay::TimelineComponent
- Inherits:
-
LocoMotion::BaseComponent
- Object
- ViewComponent::Base
- LocoMotion::BaseComponent
- Daisy::DataDisplay::TimelineComponent
- Defined in:
- app/components/daisy/data_display/timeline_component.rb
Overview
The Timeline component displays a list of events in chronological order, either vertically or horizontally. It's perfect for showing history, progress, or any sequence of events that should be displayed in order.
Constant Summary
Constants inherited from LocoMotion::BaseComponent
LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS
Instance Attribute Summary
Attributes inherited from LocoMotion::BaseComponent
Instance Method Summary collapse
Methods inherited from LocoMotion::BaseComponent
build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #initialize, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces
Methods included from LocoMotion::Concerns::InspectableComponent
Constructor Details
This class inherits a constructor from LocoMotion::BaseComponent
Instance Method Details
#before_render ⇒ Object
54 55 56 57 |
# File 'app/components/daisy/data_display/timeline_component.rb', line 54 def before_render set_tag_name(:component, :ul) add_css(:component, "timeline") end |