Class: Daisy::Layout::IndicatorComponent
- Inherits:
-
LocoMotion::BaseComponent
- Object
- ViewComponent::Base
- LocoMotion::BaseComponent
- Daisy::Layout::IndicatorComponent
- Defined in:
- app/components/daisy/layout/indicator_component.rb
Constant Summary
Constants inherited from LocoMotion::BaseComponent
LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS
Instance Attribute Summary
Attributes inherited from LocoMotion::BaseComponent
Instance Method Summary collapse
-
#before_render ⇒ Object
Sets up the component’s CSS classes.
-
#call ⇒ Object
Renders the component, all indicator items, and the main content.
Methods inherited from LocoMotion::BaseComponent
build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #initialize, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces
Methods included from LocoMotion::Concerns::InspectableComponent
Constructor Details
This class inherits a constructor from LocoMotion::BaseComponent
Instance Method Details
#before_render ⇒ Object
Sets up the component’s CSS classes.
68 69 70 |
# File 'app/components/daisy/layout/indicator_component.rb', line 68 def before_render add_css(:component, "indicator") end |
#call ⇒ Object
Renders the component, all indicator items, and the main content.
75 76 77 78 79 80 81 82 83 |
# File 'app/components/daisy/layout/indicator_component.rb', line 75 def call part(:component) do items.each do |item| concat(item) end concat(content) if content? end end |