Class: Daisy::Navigation::DockComponent

Inherits:
LocoMotion::BaseComponent show all
Defined in:
app/components/daisy/navigation/dock_component.rb

Overview

Creates a dock navigation bar, typically used in mobile-friendly applications to provide quick access to important sections.

Constant Summary

Constants inherited from LocoMotion::BaseComponent

LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS

Instance Attribute Summary

Attributes inherited from LocoMotion::BaseComponent

#config, #loco_parent

Instance Method Summary collapse

Methods inherited from LocoMotion::BaseComponent

build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces

Methods included from LocoMotion::Concerns::InspectableComponent

#build_inspect_string

Constructor Details

#initialize(*args, **kws, &block) ⇒ DockComponent

Creates a new dock component.

Parameters:

  • kws (Hash)

    The keyword arguments for the component.

Options Hash (**kws):

  • css (String)

    Additional CSS classes for styling. Common options include:

    • Position: relative, fixed bottom-0
    • Width: w-full, max-w-[400px]
    • Border: border, border-base-200
    • Size: dock-xs, dock-sm, dock-md, dock-lg, dock-xl


152
153
154
# File 'app/components/daisy/navigation/dock_component.rb', line 152

def initialize(*args, **kws, &block)
  super
end

Instance Method Details

#before_renderObject

Configure the component before rendering.

Adds the dock CSS class to the component.



159
160
161
162
163
# File 'app/components/daisy/navigation/dock_component.rb', line 159

def before_render
  add_css(:component, "dock")

  super
end

#callString

Render the dock component with all its sections and content.

Returns:

  • (String)

    The rendered HTML for the dock component.



168
169
170
171
172
173
174
175
176
# File 'app/components/daisy/navigation/dock_component.rb', line 168

def call
  part(:component) do
    sections.each do |section|
      concat(section)
    end

    concat(content)
  end
end