Class: Daisy::Navigation::MenuComponent

Inherits:
LocoMotion::BaseComponent show all
Defined in:
app/components/daisy/navigation/menu_component.rb

Overview

Note:

Vertical menus no longer have a default width. Use w-full or other width classes if you want to control the width.

Creates a menu component for displaying a list of items, optionally with group titles.

Constant Summary

Constants inherited from LocoMotion::BaseComponent

LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS

Instance Attribute Summary

Attributes inherited from LocoMotion::BaseComponent

#config, #loco_parent

Instance Method Summary collapse

Methods inherited from LocoMotion::BaseComponent

build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces

Methods included from LocoMotion::Concerns::InspectableComponent

#build_inspect_string

Constructor Details

#initialize(*args, **kws, &block) ⇒ MenuComponent

Create a new instance of the MenuComponent.

Parameters:

  • kws (Hash)

    The keyword arguments for the component.

Options Hash (**kws):

  • css (String)

    Additional CSS classes for styling. Common options include:

    • Layout: menu-horizontal, w-full, w-56
    • Background: bg-base-100, bg-neutral
    • Border: border, rounded-box
    • Shadow: shadow, shadow-lg


119
120
121
# File 'app/components/daisy/navigation/menu_component.rb', line 119

def initialize(*args, **kws, &block)
  super
end

Instance Method Details

#before_renderObject

Sets the tag name to <ul> and adds the relevant Daisy classes.



126
127
128
129
# File 'app/components/daisy/navigation/menu_component.rb', line 126

def before_render
  set_tag_name(:component, :ul)
  add_css(:component, "menu")
end