Module: Daisy::Navigation::MenuComponent::Daisy
- Defined in:
- app/components/daisy/navigation/menu_component.rb
Overview
A menu item component that can optionally have a title and be disabled.
Defined Under Namespace
Modules: Navigation
A menu item component that can optionally have a title and be disabled.
Modules: Navigation