Class: Daisy::Navigation::StepsComponent

Inherits:
LocoMotion::BaseComponent show all
Defined in:
app/components/daisy/navigation/steps_component.rb

Overview

Note:

Steps are automatically numbered and connected with lines. You can use colors to indicate progress through the steps.

Creates a component for displaying a series of steps that users can follow to complete a task. Useful for onboarding, form completion, and progress tracking.

Constant Summary

Constants inherited from LocoMotion::BaseComponent

LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS

Instance Attribute Summary

Attributes inherited from LocoMotion::BaseComponent

#config, #loco_parent

Instance Method Summary collapse

Methods inherited from LocoMotion::BaseComponent

build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces

Methods included from LocoMotion::Concerns::InspectableComponent

#build_inspect_string

Constructor Details

#initialize(*args, **kws, &block) ⇒ StepsComponent

Create a new instance of the StepsComponent.

Parameters:

  • kws (Hash)

    The keyword arguments for the component.

Options Hash (**kws):

  • css (String)

    Additional CSS classes for styling. Common options include:

    • Direction: steps-vertical
    • Size: steps-mini, steps-sm, steps-md, steps-lg
    • Width: w-full, max-w-xs


106
107
108
# File 'app/components/daisy/navigation/steps_component.rb', line 106

def initialize(*args, **kws, &block)
  super
end

Instance Method Details

#before_renderObject



110
111
112
113
114
115
# File 'app/components/daisy/navigation/steps_component.rb', line 110

def before_render
  set_tag_name(:component, :ul)
  add_css(:component, "steps")

  super
end

#callObject



117
118
119
120
121
122
123
# File 'app/components/daisy/navigation/steps_component.rb', line 117

def call
  part(:component) do
    steps.each do |step|
      concat(step)
    end
  end
end