Module: Hero

Defined in:
lib/hero.rb,
app/components/hero/icon_component.rb

Overview

Note:

By default, icons are displayed with the ‘size-5` Tailwind class. This can be overridden without using the `!` modifier because we utilize the `:where()` pseudo-class to ensure our default classes have the lowest CSS specificity.

Creates an icon component using Heroicons, a set of free, MIT-licensed high-quality SVG icons. For a complete list of available icons, visit heroicons.com.

Defined Under Namespace

Classes: IconComponent