Module: LocoMotion::Concerns::TippableComponent

Overview

Can be included in relevant components to allow a tip attribute that automatically adds the tooltip CSS class and the data-tip attribute to the component.