Class: Daisy::Actions::ModalComponent

Inherits:
LocoMotion::BaseComponent show all
Defined in:
app/components/daisy/actions/modal_component.rb

Constant Summary

Constants inherited from LocoMotion::BaseComponent

LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS

Instance Attribute Summary collapse

Attributes inherited from LocoMotion::BaseComponent

#config, #loco_parent

Instance Method Summary collapse

Methods inherited from LocoMotion::BaseComponent

build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces

Methods included from LocoMotion::Concerns::InspectableComponent

#build_inspect_string

Constructor Details

#initialize(title = nil, **kws, &block) ⇒ ModalComponent

Creates a new instance of the ModalComponent.

Parameters:

  • title (String) (defaults to: nil)

    The title of the modal. Used in both the modal header and the default trigger button.

  • kws (Hash)

    The keyword arguments for the component.

Options Hash (**kws):

  • title (String)

    The title of the modal. You can also pass this as the first argument.

  • closable (Boolean)

    If true (default), shows a close icon in the top-right corner.

  • dialog_id (String)

    A custom ID for the dialog element. If not provided, a unique ID will be generated.



115
116
117
118
119
120
121
# File 'app/components/daisy/actions/modal_component.rb', line 115

def initialize(title = nil, **kws, &block)
  super

  @dialog_id = config_option(:dialog_id, SecureRandom.uuid)
  @closable = config_option(:closable, true)
  @simple_title = config_option(:title, title)
end

Instance Attribute Details

#closableBoolean (readonly) Also known as: closable?

Returns Whether or not this dialog can be closed.

Returns:

  • (Boolean)

    Whether or not this dialog can be closed.



88
89
90
# File 'app/components/daisy/actions/modal_component.rb', line 88

def closable
  @closable
end

#dialog_idString (readonly)

Returns The unique ID for the ‘<dialog>` element.

Returns:

  • (String)

    The unique ID for the ‘<dialog>` element.



92
93
94
# File 'app/components/daisy/actions/modal_component.rb', line 92

def dialog_id
  @dialog_id
end

#simple_titleString (readonly)

Returns Accessor for the ‘title` string passed via the component config.

Returns:

  • (String)

    Accessor for the ‘title` string passed via the component config.



96
97
98
# File 'app/components/daisy/actions/modal_component.rb', line 96

def simple_title
  @simple_title
end

Instance Method Details

#before_renderObject

Sets up the component with various CSS classes and HTML attributes.



126
127
128
129
130
131
132
133
134
# File 'app/components/daisy/actions/modal_component.rb', line 126

def before_render
  setup_activator_or_button
  setup_component
  setup_backdrop
  setup_box
  setup_close_icon
  setup_title
  setup_actions
end