Class: Daisy::Feedback::AlertComponent

Inherits:
LocoMotion::BaseComponent show all
Includes:
LocoMotion::Concerns::IconableComponent, LocoMotion::Concerns::LinkableComponent
Defined in:
app/components/daisy/feedback/alert_component.rb

Constant Summary

Constants inherited from LocoMotion::BaseComponent

LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS

Instance Attribute Summary collapse

Attributes inherited from LocoMotion::BaseComponent

#config, #loco_parent

Instance Method Summary collapse

Methods included from LocoMotion::Concerns::IconableComponent

#has_icons?, #left_icon_html, #render_left_icon, #render_right_icon, #right_icon_html

Methods inherited from LocoMotion::BaseComponent

build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces

Methods included from LocoMotion::Concerns::InspectableComponent

#build_inspect_string

Constructor Details

#initialize(*args, **kws, &block) ⇒ AlertComponent

Creates a new Alert component.

Parameters:

  • args (Array)

    Positional arguments passed to the parent class.

  • kws (Hash)

    Keyword arguments for customizing the alert.

Options Hash (**kws):

  • icon (String)

    The name of the Heroicon to display at the start of the alert.

  • icon_html (Hash)

    Additional HTML attributes for the icon element. Options include ‘variant: :outline` or `variant: :solid`.

  • css (String)

    Additional CSS classes for the alert. Use ‘alert-info`, `alert-success`, `alert-warning`, or `alert-error` for different alert types.

  • style (String)

    The style of the alert.

    :info, :success, :warning, :error, :default
  • soft (Boolean)

    Use the soft style variant.

  • outline (Boolean)

    Use the outline style variant.

  • dash (Boolean)

    Use the dash style variant.

  • timeout (Integer)

    Auto-dismiss timeout in milliseconds. If nil, uses global configuration default. If false, no auto-dismiss.

  • autoclose (Boolean)

    Enable auto-dismiss using timeout. Must be true for auto-dismiss to work.

  • href (String)

    Converts alert to a clickable link.

  • action (String)

    Stimulus action to fire on click.

  • closable (Boolean)

    Show close button. Set to true to enable manual dismissal.



177
178
179
180
181
182
183
184
185
# File 'app/components/daisy/feedback/alert_component.rb', line 177

def initialize(*args, **kws, &block)
  super

  @icon = config_option(:icon)
  @timeout = config_option(:timeout)
  @autoclose = config_option(:autoclose)
  @action = config_option(:action)
  @closable = config_option(:closable, false)
end

Instance Attribute Details

#closableBoolean (readonly) Also known as: closable?

Returns Whether or not this alert can be closed.

Returns:

  • (Boolean)

    Whether or not this alert can be closed.



144
145
146
# File 'app/components/daisy/feedback/alert_component.rb', line 144

def closable
  @closable
end

Instance Method Details

#before_renderObject



191
192
193
194
195
# File 'app/components/daisy/feedback/alert_component.rb', line 191

def before_render
  setup_component

  super
end

#default_icon_sizeObject



187
188
189
# File 'app/components/daisy/feedback/alert_component.rb', line 187

def default_icon_size
  "where:size-6"
end