Class: Daisy::Navigation::DockComponent
- Inherits:
-
LocoMotion::BaseComponent
- Object
- ViewComponent::Base
- LocoMotion::BaseComponent
- Daisy::Navigation::DockComponent
- Defined in:
- app/components/daisy/navigation/dock_component.rb
Overview
Creates a dock navigation bar, typically used in mobile-friendly applications to provide quick access to important sections.
Constant Summary
Constants inherited from LocoMotion::BaseComponent
LocoMotion::BaseComponent::EMPTY_PART_IGNORED_TAGS, LocoMotion::BaseComponent::SELF_CLOSING_TAGS
Instance Attribute Summary
Attributes inherited from LocoMotion::BaseComponent
Instance Method Summary collapse
-
#before_render ⇒ Object
Configure the component before rendering.
-
#call ⇒ String
Render the dock component with all its sections and content.
-
#initialize(*args, **kws, &block) ⇒ DockComponent
constructor
Creates a new dock component.
Methods inherited from LocoMotion::BaseComponent
build, #component_ref, #config_option, #cssify, define_modifier, define_modifiers, define_part, define_parts, define_size, define_sizes, #empty_part_content, #inspect, #part, register_component_initializer, register_component_setup, #rendered_css, #rendered_data, #rendered_html, #rendered_stimulus_controllers, #rendered_tag_name, renders_many, renders_one, set_component_name, #set_loco_parent, #strip_spaces
Methods included from LocoMotion::Concerns::InspectableComponent
Constructor Details
#initialize(*args, **kws, &block) ⇒ DockComponent
Creates a new dock component.
152 153 154 |
# File 'app/components/daisy/navigation/dock_component.rb', line 152 def initialize(*args, **kws, &block) super end |
Instance Method Details
#before_render ⇒ Object
Configure the component before rendering.
Adds the dock CSS class to the component.
159 160 161 162 163 |
# File 'app/components/daisy/navigation/dock_component.rb', line 159 def before_render add_css(:component, "dock") super end |
#call ⇒ String
Render the dock component with all its sections and content.
168 169 170 171 172 173 174 175 176 |
# File 'app/components/daisy/navigation/dock_component.rb', line 168 def call part(:component) do sections.each do |section| concat(section) end concat(content) end end |